//package frameMax;

import framemax.GridPanel;
import framemax.Line;
import framemax.Oval;
import framemax.Rct;
import java.awt.*;
import java.util.*;
import javax.swing.*;

/**
 *
 * @author Yvonne V. Richardson Graphic Array Handling Lecture
 *
 * MVC implementation of a previous drawing program.
 *
 * Edition 1 drew one graphic on one DrawPanel object. Edition 2 drew one
 * graphic each on an array of DrawPanel objects. This edition replaces the
 * input scanner object with the jOptionPane object and replaces the DrawPanel
 * object with the the JPanel object.
 *
 * The way these objects work required a near-complete rewrite from the previous
 * edition. Instead of an application that draws an object on a pre-existing
 * panel, the JVM handles the drawing of the object during instantiation of the
 * panel previous to handing it to the application. Because the functionality is
 * performed by the JVM, the Graphics object that behaves as a paintbrush for
 * the panel object does not persist.
 *
 * Consequently, each shape that can be drawn has been moved to its own class.
 * The drawing of the shape has been moved to the GridPanel extension of the
 * JPanel class. The functionality of the DrawObject method has been moved to
 * those classes, and the DrawObject method no longer exists.
 *
 * The replacement of the scanner object with the JOptionPane object allowed the
 * view methods to be rewritten. Each question asks the user for similar
 * information, so there was no need to leave the question literals in the code.
 *
 * The driver that was used for the DrawPanel object is rudimentary.
 *
 */
public class FrameMax {

  /**
   * @param args the command line arguments
   */
  // This implementation is useful until it is appropriate to implement various 
  // pieces in separate classes. Many items are represented by named constants 
  // for maintainability and ease of use.
  // Shapes that can be drawn
  public static final int DRAW_OVAL = 1;
  public static final int DRAW_CIRCLE = 2;
  public static final int DRAW_RECT = 3;
  public static final int DRAW_LINE = 4;
  public static final int DRAW_SQUARE = 5;
  // Number of elements in a graphic
  public static final int OBJECTSIZE = 8;
  // Each graphic contains these states (is determined by its attributes or 
  //   has these properties)	 
  static int[] ObjectToDraw = new int[OBJECTSIZE]; //   1D array of properties	
  public static final int idxShape = 0;
  public static final int idxColor = 1;
  public static final int idxInterior = 2;
  public static final int idxDim1 = 3;
  public static final int idxDim2 = 4;
  public static final int idxOrigin1 = 5;
  public static final int idxOrigin2 = 6;
  public static final int ENDPAINT = 99;
  public static final String strNumberRange1 = "Number out of range, please enter another";
  public static boolean Done;
  public static final int GRIDS = 3;
  // Debugging statements turned on or off
  public static final boolean TODEBUG = false;
  static int intStatement = 0;
  static Color colorToPaintInterior;
  static Color colorToPaintColor;

  public static void main(String[] args) {
    // MVC MODEL - CONTROLLER METHOD
    //

    // The screen object is a JFrame object
    JFrame frame = new JFrame();
    frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    frame.setSize(new Dimension(800, 600));
    frame.setTitle("ArayMax as JFrames");
    frame.setLayout(new BorderLayout());
    frame.setLocation(100, 100);

    // The frame has one container, separated into 3 sections
    Container frContainer = frame.getContentPane();
    frContainer.setLayout(new BorderLayout());

    // north and south portions of the GUI will be defined later
    JPanel north = new JPanel(new FlowLayout());
    JPanel south = new JPanel(new FlowLayout());
    frContainer.add(north, BorderLayout.NORTH);
    frContainer.add(south, BorderLayout.SOUTH);

    // The object to draw on the screen is a 2D array of graphics
    //   objects.  it has its own panel in the center of the GUI

// Define and initialize the screen object in a 2d array
    JPanel grid1 = new JPanel(new GridLayout(GRIDS, GRIDS));

    // MODEL METHOD - methods that are not associated with user interaction

    int intRowChoice = 0;
    int intColChoice = 0;
    // Initialize 2d array with information required to instantiate
    //   each object in it
    for (int row = 0; row < GRIDS; row++) {
      for (int col = 0; col < GRIDS; col++) {
        // acquire all of the object properties, including the colors
        getObject(ObjectToDraw);

        switch (ObjectToDraw[idxShape]) {
          case DRAW_LINE: {
            Line linGraphic = new Line(ObjectToDraw[idxOrigin1], ObjectToDraw[idxOrigin2], ObjectToDraw[idxDim1], ObjectToDraw[idxDim2], colorToPaintColor);
            GridPanel gridSquare = new GridPanel(linGraphic);
            grid1.add(gridSquare);
            break;
          }
          case DRAW_OVAL:
          case DRAW_CIRCLE: {
            Oval ovlGraphic = new Oval(ObjectToDraw[idxOrigin1], ObjectToDraw[idxOrigin2], ObjectToDraw[idxDim1], colorToPaintColor, colorToPaintInterior);
            // radius 2 later
            GridPanel gridSquare = new GridPanel(ovlGraphic);
            grid1.add(gridSquare);
            break;
          }
          case DRAW_RECT:
          case DRAW_SQUARE: {
            Rct rctGraphic = new Rct(ObjectToDraw[idxDim1], ObjectToDraw[idxDim2], ObjectToDraw[idxOrigin1], ObjectToDraw[idxOrigin2], colorToPaintColor, colorToPaintInterior);
            GridPanel gridSquare = new GridPanel(rctGraphic);
            grid1.add(gridSquare);
            break;
          }
          default:
            JOptionPane.showMessageDialog(null, "drawing default");
// discrepancy between user choices and program options 
            GridPanel gridSquare = new GridPanel(Color.white);
            grid1.add(gridSquare);
        } // end switch
      }  // for int col
    }  // for int row

    frContainer.add(grid1, BorderLayout.CENTER);
    frame.pack();
    frame.setVisible(true);
  }  // end main

  public static void getObject(int[] ObjectToDraw) {
    // Acquire the properties of the graphic to draw 	

    // MVC MODEL - VIEW METHODS
    //   Handles interaction with user, which is 
    //   usually console I/O
    //
    // This method was re-written to acquire information by using the 
    //   JOptionPane object  instead of the scanner object. Questions 
    //   that are parameterized are sent to fewer methods.
    //
    String strShapeQuestion = "Object to draw: 1 = Oval, 2 = Circle, 3 = Rectangle, 4 = Line, 5 = Square";
    String strInteriorQuestion = "Interior color: 1 = Black, 2 = White, 3 = Red, 4 = Blue, 5=Green";
    String strExteriorQuestion = "Outline color: 1 = Black, 2 = White, 3 = Red, 4 = Blue, 5=Green";
    String strXOriginQuestion = "Enter the x-coordinate of the origin";
    String strYOriginQuestion = "Enter the y-coordinate of the origin";
    String strXCoordQuestion = "Enter the x-coordinate of the endpoint";
    String strYCoordQuestion = "Enter the y-coordinate of the endpoint";
    String strHeightQuestion = "Enter the height of the object";
    String strLengthQuestion = "Enter the length of the object";

    int intLowerRange = 1;
    int intUpperRange = 5;
    // Trace debug statements - standard in the absence of 
    //   a compiler directive  
    if (TODEBUG) {
      ++intStatement;
      System.out.printf("Debugging statement: %3d\n", intStatement);
    }

    // The following questions prompt the user for information about 
    //   the graphic to draw.  The first one allows the user to use the 
    //   sentinel value to stop the program		

    int UserChoice = askRange(strShapeQuestion, intLowerRange, intUpperRange);
    // the shape to display

    if (UserChoice == ENDPAINT) {
      Done = true;
    } else {
      // Store the shape information in the 1D array
      //  that represents the graphic object
      ObjectToDraw[idxShape] = UserChoice;

      if (TODEBUG) {
        ++intStatement;
        System.out.printf("Debugging statement: %3d\n", intStatement);
      }

      // the color of the outline of the shape
      ObjectToDraw[idxColor] = askRange(strExteriorQuestion, intLowerRange, intUpperRange);

      // initialize a color object with the color of the shape
      switch (ObjectToDraw[idxColor]) {
        case 1:
          colorToPaintColor = Color.BLACK;
          break;
        case 2:
          colorToPaintColor = Color.WHITE;
          break;
        case 3:
          colorToPaintColor = Color.RED;
          break;
        case 4:
          colorToPaintColor = Color.BLUE;
          break;
        case 5:
          colorToPaintColor = Color.GREEN;
          break;
        default:
          colorToPaintColor = Color.MAGENTA;
      }

      if (TODEBUG) {
        ++intStatement;
        System.out.printf("Debugging statement: %3d\n", intStatement);
      }

      // the color of the interior of the shape
      //  a line does not contain an interior
      if (ObjectToDraw[idxShape] != DRAW_LINE) {

        ObjectToDraw[idxInterior] = askRange(strInteriorQuestion, intLowerRange, intUpperRange);

        // initialize a second color object with the color of the interior
        switch (ObjectToDraw[idxInterior]) {
          case 1:
            colorToPaintInterior = Color.BLACK;
            break;
          case 2:
            colorToPaintInterior = Color.WHITE;
            break;
          case 3:
            colorToPaintInterior = Color.RED;
            break;
          case 4:
            colorToPaintInterior = Color.BLUE;
            break;
          case 5:
            colorToPaintInterior = Color.GREEN;
            break;
          default:
            colorToPaintInterior = Color.BLUE;
        }

        if (TODEBUG) {
          ++intStatement;
          System.out.printf("Debugging statement: %3d\n", intStatement);
        }
      }
// Acquire the horizonal dimension of the shape
// All items have at least one dimension. Rectangles and ovals have two dimensions.
// Squares and circles use the same dimension twice. Lines have 2 endpoints 
// instead of 2 dimensions

      if (ObjectToDraw[idxShape] == DRAW_LINE) {
        // ask for 2 numbers, which are the x-y coordinates of the endpoint
        ObjectToDraw[idxDim1] = askRange(strXCoordQuestion);
        ObjectToDraw[idxDim2] = askRange(strYCoordQuestion);
      } else if ((ObjectToDraw[idxShape] == DRAW_OVAL) || (ObjectToDraw[idxShape] == DRAW_RECT)) {
        // ask for 2 numbers, which are the length/height 
        ObjectToDraw[idxDim1] = askRange(strHeightQuestion);
        if (ObjectToDraw[idxShape] == DRAW_OVAL) {
          ObjectToDraw[idxDim2] = askRange(strLengthQuestion);
        } else {
          ObjectToDraw[idxDim2] = ObjectToDraw[idxDim1];
        }
      } else {
        // default is square

        // ask for 2 numbers, which are the length/height 
        // same number used twice is radius or length
        ObjectToDraw[idxDim1] = askRange(strLengthQuestion);

        if (ObjectToDraw[idxShape] == DRAW_RECT) {
          ObjectToDraw[idxDim2] = askRange(strHeightQuestion);
        } else {
          ObjectToDraw[idxDim2] = ObjectToDraw[idxDim1];
        }
      }

      if (TODEBUG) {
        ++intStatement;
        System.out.printf("Debugging statement: %3d\n", intStatement);
      }

      // The last question is the origin (x,y) of the graphic
      // This is also the second endpoint of a line
      ObjectToDraw[idxOrigin1] = askRange(strXOriginQuestion);
      ObjectToDraw[idxOrigin2] = askRange(strYOriginQuestion);
      if (TODEBUG) {
        ++intStatement;
        System.out.printf("Debugging statement: %3d\n", intStatement);
      }
    }    // else (UserChoice != ENDPAINT) 
  }  // end getObject

  public static int askRange(String strQuestion, int intLowerRange, int intUpperRange) {
    // These are the methods that acquire specific properties from the user
    int intAnswer = 0;
    String strAnswer;

    Object message = strQuestion;
    Object objNumberRange = strNumberRange1;

    strAnswer = JOptionPane.showInputDialog(null, message);
    intAnswer = Integer.parseInt(strAnswer);

    if (intAnswer != ENDPAINT) {
      while ((intAnswer < intLowerRange) || (intAnswer > intUpperRange)) {
        JOptionPane.showMessageDialog(null, objNumberRange);
        strAnswer = JOptionPane.showInputDialog(null, message);
        intAnswer = Integer.parseInt(strAnswer);
      }
    }
    return intAnswer;
  }  // end askRange

  public static int askRange(String strQuestion) {
    // These are the methods that acquire specific properties from the user
    // This method does not check range of user choices 
    int intAnswer = 0;
    String strAnswer;

    Object message = strQuestion;

    strAnswer = JOptionPane.showInputDialog(null, message);
    intAnswer = Integer.parseInt(strAnswer);

    return intAnswer;
  }  // end askRange
} // end class

