package framemax;

import java.awt.*;
import java.util.*;
import javax.swing.*;

/**
 *
 * @author Yvonne V. Richardson Graphic Array Handling Lecture
 *
 * MVC implementation of a previous drawing program.
 *
 * Edition 1 drew one graphic on one DrawPanel object. Edition 2 drew one
 * graphic each on an array of DrawPanel objects. This edition replaces the
 * input scanner object with the jOptionPane object and replaces the DrawPanel
 * object with the the JPanel object.
 *
 * The way these objects work required a near-complete rewrite from the previous
 * edition. Instead of an application that draws an object on a pre-existing
 * panel, the JVM handles the drawing of the object during instantiation of the
 * panel previous to handing it to the application. Because the functionality is
 * performed by the JVM, the Graphics object that behaves as a paintbrush for
 * the panel object does not persist.
 *
 * The GridPanel extension of the JPanel class contains the functionality that
 * draws each shape.
 */
public class GridPanel extends JPanel {

  private Line Line1;
  private Oval Oval1;
  private Rct Rct1;

  // constructors
  public GridPanel() {
    setBackground(Color.white);
  }

  public GridPanel(Color backColor) {
    setBackground(backColor);
  }

  public GridPanel(Line l1) {
    Line1 = l1;
    setBackground(Color.white);
  }

  public GridPanel(Oval o1) {
    Oval1 = o1;
    setBackground(Color.white);
  }

  public GridPanel(Rct r1) {
    Rct1 = r1;
    setBackground(Color.white);
  }

  public void paintComponent(Graphics g) {
    // The application cannot call the paintComponent directly; 
    // this method is triggered automatically by the JVM in 
    // response to certain events
    super.paintComponent(g);
    if (Line1 != null) {
      Line1.draw(g);
    }

    if (Oval1 != null) {
      Oval1.draw(g);
      if (!(Oval1.getColor().equals(Oval1.getFillColor()))) {
        Oval1.fill(g);
      }
    }
    
    if (Rct1 != null) {
      Rct1.draw(g);
      if (!(Rct1.getColor().equals(Rct1.getFillColor()))) {
        Rct1.fill(g);
      }
    }

  } // paintcomponent
} // end class