
package framemax;

import java.awt.*;

/**
 *
 * @author Yvonne V. Richardson Graphic Array Handling Lecture
 *
 * Each shape that can be drawn is contained in its own class. The drawing 
 * methods for the shape are contained in the class, but the GridPanel extension 
 * of the JPanel class contains the paintComponent method that calls the
 * methods within the shape.
 */
public class Oval {
  // Each object to be drawn is prescribed in its own class
  // The JVM automatically triggers the paintComponent to
  // draw the shape in response to certain events

  private int centerX, centerY, radius;
  private Color color, fillColor;

  // constructors
  public Oval() {
    centerX = 0;
    centerY = 0;
    radius = 0;
    color = Color.WHITE;
    fillColor = Color.WHITE;
  }
  
  public Oval(int x, int y, int r, Color c) {
    centerX = x;
    centerY = y;
    radius = r;
    color = c;
    fillColor =c;
  }
    public Oval(int x, int y, int r, Color c, Color fillc) {
    centerX = x;
    centerY = y;
    radius = r;
    color = c;
    fillColor =fillc;
  }


  // accessors for private instance variables
  public int X() {
    // returns the x coordinate of the center
    return centerX;
  }
  
  public int getX() {
    // returns the x coordinate of the center
    return centerX;
  }

  public int Y() {
    // returns the y coordinate of the center
    return centerY;
  }
public int getY() {
    // returns the y coordinate of the center
    return centerY;
  }
  
  public int Radius() {
    // returns the radius 
    return radius;
  }

  public int getRadius() {
    // returns the radius 
    return radius;
  }

  public Color color() {
    // returns the color object
    return color;
  }

  public Color getColor() {
    // returns the color object
    return color;
  }

  public Color FillColor() {
    // returns the color object when the interior of the object is a
    //   different color
    return fillColor;
  }

  public Color getFillColor() {
    // returns the color object when the interior of the object is a
    //   different color
    return fillColor;
  }

    // mutators for private instance variables
  public void setX(int x) {
    // sets the x coordinate of the center
    centerX = x;
  }

  public void setY(int y) {
    // sets the y coordinate of the center
    centerY = y;
  }

  public void setRadius(int r) {
    // sets the radius 
    radius = r;
  }

  public Color setColor(Color c) {
    // sets the color object
    color = c;
    return color;
  }

  public Color setFillColor(Color c) {
    // sets the color object
    fillColor = c;
    return fillColor;
  }
  
// overrides from inherited classes
  public String toString() {
    String objHelp = "x is " +
            Integer.toString(centerX) + ", y is "
            + Integer.toString(centerY) + ", radius is "
            + Integer.toString(radius) + ", color is "
            + color.toString() + ", fill color is "
            + fillColor.toString();
    return objHelp;
  }

  public void draw(Graphics g) {
    // Save the current color of the graphics context
    //   and set color to the color of the oval
    Color oldColor = g.getColor();
    g.setColor(color);
    // Translate the oval's position and radii
    // to the bounding rectangle's top left corner, width, and height.
    // Translate radius to diameter
    g.drawOval(centerX - radius, centerY - radius, radius * 2, radius * 2);
    // Restore the color of the graphics context
    
    g.setColor(oldColor);
  }

  public void fill(Graphics g) {
    Color oldColor = g.getColor();
    g.setColor(color);
    // Translates the center of the oval to the origin of the rectangle for drawing
    g.fillOval(centerX - radius+3, centerY - radius+3, radius * 2+3, radius * 2+3);
    // Restore the color of the graphics context
    g.setColor(oldColor);
  }

  public boolean containsPoint(int x, int y) {
    int xSquared = (x - centerX) * (x - centerX);
    int ySquared = (y - centerY) * (y - centerY);
    int radiusSquared = radius * radius;
    return xSquared + ySquared - radiusSquared <= 0;
  }

  public void move(int xAmount, int yAmount) {
    centerX = centerX + xAmount;
    centerY = centerY + yAmount;

  }
} // class Oval
