package framemax;

import java.awt.*;

/**
 *
 * @author Yvonne V. Richardson Graphic Array Handling Lecture
 *
 * Each shape that can be drawn is contained in its own class. The drawing 
 * methods for the shape are contained in the class, but the GridPanel extension 
 * of the JPanel class contains the paintComponent method that calls the
 * methods within the shape.
 */
public class Rct {
  // Each object to be drawn is prescribed in its own class
  // The JVM automatically triggers the paintComponent to
  // draw the shape in response to certain events

  private int Width, Height;
  private int XPos, YPos;   // top left corner
  private Color color, fillColor;

  // constructors
  public Rct() {
    Width = 0;
    Height = 0;
    XPos = 0;
    YPos = 0;
    color = Color.WHITE;
    fillColor = Color.WHITE;
  }
  
  public Rct(int width, int height, int x, int y, Color c) {
    Width = width;
    Height = height;
    XPos = x;
    YPos = y;
    color = c;
    fillColor = c;
  }
  public Rct(int width, int height, int x, int y, Color c, Color fillc) {
    Width = width;
    Height = height;
    XPos = x;
    YPos = y;
    color = c;
    fillColor = fillc;
  }
  
  // accessors for private instance variables
 public int Width() {
    // returns the Width coordinate of the rectangle
    return Width;
  }

 public int getWidth() {
    // returns the Width coordinate of the rectangle
    return Width;
  }
  
public int Height() {
    // returns the Height coordinate of the rectangle
    return Height;
  }
 
  public int getHeight() {
    // returns the Height coordinate of the rectangle
    return Height;
  }

  public int XPos() {
    // returns the x coordinate of the top left corner of the rectangle
    return XPos;
  }

  public int getXPos() {
    // returns the x coordinate of the top left corner of the rectangle
    return XPos;
  }
  
 public int YPos() {
    // returns the y coordinate of the top left corner of the rectangle

    return YPos;
  }

  public int getYPos() {
    // returns the y coordinate of the top left corner of the rectangle

    return YPos;
  }
  
  public Color color() {
    // returns the color object
    return color;
  }

  public Color getColor() {
    // returns the color object
    return color;
  }

  public Color FillColor() {
    // returns the color object
    return fillColor;
  }
  
  public Color getFillColor() {
    // returns the color object
    return fillColor;
  }
  
    // mutators for private instance variables
  public void setWidth(int width) {
    // sets the width coordinate of the rectangle
    Width = width;
  }

  public void setHeight(int height) {
    // sets the Height coordinate of the rectangle
    Height = height;
  }

  public void setXPos(int x) {
    // sets the width coordinate of the rectangle
    XPos = x;
  }

  public void setYPos(int y) {
    // sets the Height coordinate of the rectangle
    YPos = y;
  }

  public Color setColor(Color c) {
    // sets the color object
    color = c;
    return color;
  }

  public Color setFillColor(Color c) {
    // sets the fill color object
    fillColor = c;
    return fillColor;
  }

// overrides from inherited classes
    public String toString() {
    String objHelp = "Top Left xPos is " +
            Integer.toString(XPos) + ", YPos is "
            + Integer.toString(YPos) + ", width is "
            + Integer.toString(Width) + ", height is "
            + Integer.toString(Height) + ", color is "
            + color.toString() + ", fill color is "
            + fillColor.toString();
    return objHelp;
  }
    
  public void draw(Graphics g) {
    // Save the current color of the graphics context
    //   and set color to the color of the rectangle
    Color oldColor = g.getColor();
    g.setColor(color);
    // Translate the rectangle's position and dimensions
    // to the bounding rectangle's top left corner, width, and height.
    g.drawRect(XPos, XPos, Width, Height);
    // Restore the color of the graphics context
    g.setColor(oldColor);
  }

  public void fill(Graphics g) {
    Color oldColor = g.getColor();
    g.setColor(color);
    // Translate the rectangle's position and dimensions
    // to the bounding rectangle's top left corner, width, and height.
    g.fillRect(XPos + 3, XPos + 3, Width + 6, Height + 6);
    // Restore the color of the graphics context
    g.setColor(oldColor);
  }

  public void move(int xAmount, int yAmount) {
    XPos = XPos + xAmount;
    YPos = YPos + yAmount;

  }
} // class Rct
